pybedtools.scripts.intron_exon_reads
====================================

.. automodule:: pybedtools.scripts.intron_exon_reads

   
   
   .. rubric:: Functions

   .. autosummary::
   
      count_reads_in_features
      featuretype_filter
      main
      subset_featuretypes
   
   

   
   
   

   
   
   